@@ -1,12 +1,13 @@
 import requests, sys, json, base64
+from urllib.parse import quote
 
 base_parameters={
     "api-version":"7.1-preview.1"
 }
 
-def create_headers(TOKEN=str) -> str:
-    credenciales = f"{TOKEN}"
-    credenciales_base64 = base64.b64encode(credenciales.encode('utf-8')).decode('utf-8')
+def encode_token(TOKEN=str) -> str:
+    credenciales = f"Basic:{TOKEN}"
+    credenciales_base64 = base64.b64encode(credenciales.encode()).decode('utf-8')
     return credenciales_base64
 
 def create_pr(API_URL=str, TOKEN=str, REPO_ID=str, sourceRefName=str, targetRefName=str, pr_title=str, headers=object|None, data=object|None, params=object|None) -> object:
@@ -49,7 +50,7 @@ def create_pr(API_URL=str, TOKEN=str, REPO_ID=str, sourceRefName=str, targetRefN
     base_headers = {
         'Content-Type': 'application/json',
         'Accept': 'application/json',
-        "Authorization": f"Basic {TOKEN}"
+        "Authorization": f"Basic {encode_token(TOKEN)}"
     }
     if params is not None and isinstance(params, dict):
         base_parameters.update(params)
@@ -114,7 +115,7 @@ def get_pr_data(API_URL=str, TOKEN=str, REPO_ID=str, sourceRefName=str, targetRe
     base_headers={
         "Content-Type": "application/json",
         "Accept": "application/json",
-        "Authorization": f"Basic {TOKEN}"
+        "Authorization": f"Basic {encode_token(TOKEN)}"
     }
     base_parameters.update(parameters_get_prs)
     if params is not None and isinstance(params, dict):
@@ -138,7 +139,7 @@ def get_pr_data(API_URL=str, TOKEN=str, REPO_ID=str, sourceRefName=str, targetRe
         print(f"Error al obtener datos de la PR: \n {e.strerror}")
         sys.exit(1)
 
-def add_reviwer(API_URL=str, TOKEN=str, REPO_ID=str, pullRequestId=str, reviewerId=str, headers=object|None, data=object|None, params=object|None) -> object:
+def add_reviwer(API_URL=str, PROJECT=str, TOKEN=str, REPO_ID=str, pullRequestId=str, reviewerId=str, headers=object|None, data=object|None, params=object|None) -> object:
     """
     Adds a required reviewer to a Pull Request.
 
@@ -174,7 +175,7 @@ def add_reviwer(API_URL=str, TOKEN=str, REPO_ID=str, pullRequestId=str, reviewer
     base_headers={
         "Content-Type": "application/json",
         "Accept": "application/json",
-        "Authorization": f"Basic {TOKEN}"
+        "Authorization": f"Basic {encode_token(TOKEN)}"
     }
     if params is not None and isinstance(params, dict):
         base_parameters.update(params)
@@ -183,15 +184,15 @@ def add_reviwer(API_URL=str, TOKEN=str, REPO_ID=str, pullRequestId=str, reviewer
     if data is not None and isinstance(data, dict):
         body.update(data)
     try:
-        response = requests.put(url=f"{API_URL}/repositories/{REPO_ID}/pullrequests/{pullRequestId}/reviewers/{reviewerId}", headers=base_headers, params=base_parameters, data=json.dumps(body))
+        response = requests.put(url=f"{API_URL}/{quote(PROJECT)}/repositories/{REPO_ID}/pullrequests/{pullRequestId}/reviewers/{reviewerId}", headers=base_headers, params=base_parameters, data=json.dumps(body))
         if response.status_code == 200:
             json_response={
-                "funcition_code":200,
+                "function_code":200,
                 "message":f"Revisor {response['displayName']} agregado correctamente a la PR {pullRequestId}."
             }
         else:
             json_response={
-                "funcition_code":f"{response.status_code}",
+                "function_code":f"{response.status_code}",
                 "message":f"{response.text}"
             }
         return json_response
@@ -199,7 +200,7 @@ def add_reviwer(API_URL=str, TOKEN=str, REPO_ID=str, pullRequestId=str, reviewer
         print(f"Error al añadir un reviwer: \n {e.strerror}")
         sys.exit(1)
 
-def approve_pr(API_URL=str, TOKEN=str, REPO_ID=str, pullRequestId=str, reviewerId=str, headers=object|None, data=object|None, params=object|None) -> object:
+def approve_pr(API_URL=str, PROJECT=str, TOKEN=str, REPO_ID=str, pullRequestId=str, reviewerId=str, headers=object|None, data=object|None, params=object|None) -> object:
     """
     Approves a Pull Request as a reviewer.
 
@@ -232,7 +233,7 @@ def approve_pr(API_URL=str, TOKEN=str, REPO_ID=str, pullRequestId=str, reviewerI
         "vote": 10  # 10 significa que el revisor aprueba la PR
     }
     base_headers={
-        "Authorization": f"Basic {TOKEN}"
+        "Authorization": f"Basic {encode_token(TOKEN)}"
     }
     if params is not None and isinstance(params, dict):
         base_parameters.update(params)
@@ -241,15 +242,15 @@ def approve_pr(API_URL=str, TOKEN=str, REPO_ID=str, pullRequestId=str, reviewerI
     if data is not None and isinstance(data, dict):
         body.update(data)
     try:
-        response = requests.put(url=f"{API_URL}/repositories/{REPO_ID}/pullrequests/{pullRequestId}/reviewers/{reviewerId}", headers=base_headers, data=json.dumps(body), params=base_parameters)
+        response = requests.put(url=f"{API_URL}/{quote(PROJECT)}/repositories/{REPO_ID}/pullrequests/{pullRequestId}/reviewers/{reviewerId}", headers=base_headers, data=json.dumps(body), params=base_parameters)
         if response.status_code == 200:
             json_response={
-                "funcition_code":200,
-                "message":f"Revisor {response['displayName']} ha aprobado la PR {pullRequestId}."
+                "function_code":200,
+                "message":f"Revisor {json.loads(response.text)['displayName']} ha aprobado la PR {pullRequestId}."
             }
         else:
             json_response={
-                "funcition_code":f"{response.status_code}",
+                "function_code":f"{response.status_code}",
                 "message":f"{response.text}"
             }
         return json_response
@@ -257,7 +258,7 @@ def approve_pr(API_URL=str, TOKEN=str, REPO_ID=str, pullRequestId=str, reviewerI
         print(f"Error al aprobar la pr: \n {e.strerror}")
         sys.exit(1)
 
-def complete_pr(API_URL=str, TOKEN=str, REPO_ID=str, pullRequestId=str, commitData=str, headers=object|None, data=object|None, params=object|None) -> object:
+def complete_pr(API_URL=str, PROJECT=str, TOKEN=str, REPO_ID=str, pullRequestId=str, commitData=str, headers=object|None, data=object|None, params=object|None) -> object:
     """
     Completes (merges) a Pull Request.
 
@@ -301,7 +302,7 @@ def complete_pr(API_URL=str, TOKEN=str, REPO_ID=str, pullRequestId=str, commitDa
     base_headers={
         "Content-Type": "application/json",
         "Accept": "application/json",
-        "Authorization": f"Basic {TOKEN}"
+        "Authorization": f"Basic {encode_token(TOKEN)}"
     }
     if params is not None and isinstance(params, dict):
         base_parameters.update(params)
@@ -310,15 +311,15 @@ def complete_pr(API_URL=str, TOKEN=str, REPO_ID=str, pullRequestId=str, commitDa
     if data is not None and isinstance(data, dict):
         body.update(data)
     try:
-        response = requests.post(url=f"{API_URL}/repositories/{REPO_ID}/pullrequests/{pullRequestId}", headers=base_headers, data=json.dumps(body), params=base_parameters)
+        response = requests.post(url=f"{API_URL}/{quote(PROJECT)}/repositories/{REPO_ID}/pullrequests/{pullRequestId}", headers=base_headers, data=json.dumps(body), params=base_parameters)
         if response.status_code == 200:
             json_response={
-                "funcition_code":200,
+                "function_code":200,
                 "message":f"PR {pullRequestId} completada y mergeada correctamente."
             }
         else:
             json_response={
-                "funcition_code":f"{response.status_code}",
+                "function_code":f"{response.status_code}",
                 "message":f"{response.text}"
             }
         return json_response
@@ -356,7 +357,7 @@ def get_project(API_URL=str, TOKEN=str, name=str, headers=object|None, params=ob
 
     base_headers = {
         'Accept': 'application/json',
-        'Authorization': f'Basic {TOKEN}'
+        'Authorization': f'Basic {encode_token(TOKEN)}'
     }
     if params is not None and isinstance(params, dict):
         base_parameters.update(params)
@@ -365,16 +366,18 @@ def get_project(API_URL=str, TOKEN=str, name=str, headers=object|None, params=ob
     try:
         response = requests.get(url=f"{API_URL}/_apis/projects", headers=base_headers, params=base_parameters)
         if response.status_code == 200:
-            for project in response['value']:
-                if project['name'] == name:
+            for project in json.loads(response.text)['value']:
+                if name in project['name']:
                     json_response={
-                        "funcition_code":200,
+                        "function_code":200,
                         "projectId": f"{project['id']}",
                         "message":f"Obtencion de projectos correcto"
                     }
+                    break
+
         else:
             json_response={
-                "funcition_code":f"{response.status_code}",
+                "function_code":f"{response.status_code}",
                 "projectId": "0",
                 "message":f"{response.text}"
             }
@@ -414,7 +417,7 @@ def get_teams_by_projectId(API_URL=str, TOKEN=str, REPO_ID=str, project_id=str,
 
     base_headers = {
         'Accept': 'application/json',
-        'Authorization': f'Basic {TOKEN}'
+        'Authorization': f'Basic {encode_token(TOKEN)}'
     }
     if params is not None and isinstance(params, dict):
         base_parameters.update(params)
@@ -423,16 +426,17 @@ def get_teams_by_projectId(API_URL=str, TOKEN=str, REPO_ID=str, project_id=str,
     try:
         response = requests.get(url=f"{API_URL}/_apis/projects/{project_id}/teams", headers=base_headers, params=base_parameters)
         if response.status_code == 200:
-            for team in response['value']:
-                if team['name'] == team_name:
+            for team in json.loads(response.text)['value']:
+                if team_name in team['name']:
                     json_response={
-                        "funcition_code":200,
+                        "function_code":200,
                         "teamId": f"{team['id']}",
                         "message":f"Obtencion de equipos correcto"
                     }
+                    break
         else:
             json_response={
-                "funcition_code":f"{response.status_code}",
+                "function_code":f"{response.status_code}",
                 "teamId": "0",
                 "message":f"{response.text}"
             }
@@ -473,7 +477,7 @@ def get_reviewer_id_by_team_id(API_URL=str, TOKEN=str, REPO_ID=str, project_id=s
 
     base_headers = {
         'Accept': 'application/json',
-        'Authorization': f'Basic {TOKEN}'
+        'Authorization': f'Basic {encode_token(TOKEN)}'
     }
     if params is not None and isinstance(params, dict):
         base_parameters.update(params)
@@ -482,16 +486,17 @@ def get_reviewer_id_by_team_id(API_URL=str, TOKEN=str, REPO_ID=str, project_id=s
     try:
         response = requests.get(url=f"{API_URL}/_apis/projects/{project_id}/teams/{team_id}/members", headers=base_headers, params=base_parameters)
         if response.status_code == 200:
-            for user in response:
+            for user in json.loads(response.text)['value']:
                 if user['uniqueName'] == user_email:
                     json_response={
-                        "funcition_code":200,
+                        "function_code":200,
                         "reviwerId": f"{user['id']}",
                         "message":f"Obtencion de Id de usuario correcto"
                     }
+                    break
         else:
             json_response={
-                "funcition_code":f"{response.status_code}",
+                "function_code":f"{response.status_code}",
                 "reviwerId": "0",
                 "message":f"{response.text}"
             }
@@ -500,7 +505,7 @@ def get_reviewer_id_by_team_id(API_URL=str, TOKEN=str, REPO_ID=str, project_id=s
         print(f"Error al obtener los miembros del equipo: \n {e.strerror}")
         sys.exit(1)
 
-def get_repo_id(API_URL=str, TOKEN=str, repo_name=str, headers=object|None, params=object|None) -> object:
+def get_repo_id(API_URL=str, PROJECT=str, TOKEN=str, repo_name=str, headers=object|None, params=object|None) -> object:
     """
     Retrieves the reviewer ID by team ID and user email.
 
@@ -530,25 +535,26 @@ def get_repo_id(API_URL=str, TOKEN=str, repo_name=str, headers=object|None, para
 
     base_headers = {
         'Accept': 'application/json',
-        'Authorization': f'Basic {TOKEN}'
+        'Authorization': f'Basic {encode_token(TOKEN)}'
     }
     if params is not None and isinstance(params, dict):
         base_parameters.update(params)
     if headers is not None and isinstance(headers, dict):
         base_headers.update(headers)
     try:
-        response = requests.get(url=f"{API_URL}/_apis/repositories", headers=base_headers, params=base_parameters)
+        response = requests.get(url=f"{API_URL}/{quote(PROJECT)}/_apis/git/repositories", headers=base_headers, params=base_parameters)
         if response.status_code == 200:
-            for repos in response:
-                if repos['uniqueName'] == repo_name:
+            for repos in json.loads(response.text)['value']:
+                if repos['name'] == repo_name:
                     json_response={
-                        "funcition_code":200,
+                        "function_code":200,
                         "repoId": f"{repos['id']}",
                         "message":f"Obtencion de Id de usuario correcto"
                     }
+                    break
         else:
             json_response={
-                "funcition_code":f"{response.status_code}",
+                "function_code":f"{response.status_code}",
                 "repoId": "0",
                 "message":f"{response.text}"
             }
@@ -556,4 +562,3 @@ def get_repo_id(API_URL=str, TOKEN=str, repo_name=str, headers=object|None, para
     except requests.RequestException as e:
         print(f"Error al obtener los miembros del equipo: \n {e.strerror}")
         sys.exit(1)
-
